@@ -54,7 +54,7 @@ class BarcodeValidator : public TQValidator {
   * supported by KBarcode.
   */
 class BarcodeCombo : public KComboBox  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public: 
         BarcodeCombo(TQWidget *parent=0, const char *name=0);
@@ -80,7 +80,7 @@ class TQLabel;
   * @author Dominik Seichter
   */
 class BarcodeWidget : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         BarcodeWidget(TQWidget *parent=0, const char *name=0);
