@@ -42,7 +42,7 @@ class TQVBox;
 class TQWidgetStack;
 
 class BatchWizard : public KWizard, public BatchIface {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         BatchWizard( TQWidget* parent = NULL, const char* name = NULL );
