@@ -192,7 +192,7 @@ void ConfigDialog::setupTab4()
     date = new KLineEdit( box );
     labelDate = new TQLabel( box );
     
-    connect( date, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( updateDatePreview() ) );
+    connect( date, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( updateDatePreview() ) );
 
     spinGrid = new KIntNumInput( 0, box );
     spinGrid->setLabel( i18n("Grid:" ), AlignLeft | AlignVCenter );
@@ -217,7 +217,7 @@ void ConfigDialog::setupTab5()
     TQVBoxLayout* tabLayout = new TQVBoxLayout( box, 11, 6 );
 
     TQButtonGroup* bg = new TQButtonGroup( i18n("On New Article"), box );
-    bg->setColumnLayout(0, Qt::Vertical );
+    bg->setColumnLayout(0, TQt::Vertical );
     bg->layout()->setSpacing( 6 );
     bg->layout()->setMargin( 11 );
     TQGridLayout* bgLayout = new TQGridLayout( bg->layout() );
@@ -258,7 +258,7 @@ void ConfigDialog::setupTab5()
     bgLayout->addWidget( onNewArticle4, 3, 1 );
 
     TQButtonGroup* bg2 = new TQButtonGroup( i18n("On New Group"), box );
-    bg2->setColumnLayout(0, Qt::Vertical );
+    bg2->setColumnLayout(0, TQt::Vertical );
     bg2->layout()->setSpacing( 6 );
     bg2->layout()->setMargin( 11 );
     TQGridLayout* bg2Layout = new TQGridLayout( bg2->layout() );
