@@ -50,7 +50,7 @@
 #include "textlineitem.h"
 //NY34
 
-// QT includes
+// TQt includes
 #include <tqbuffer.h>
 #include <tqcanvas.h>
 #include <tqcheckbox.h>
@@ -77,29 +77,29 @@
 #include <tqxml.h>
 
 // KDE includes
-#include <kabc/stdaddressbook.h>
-#include <kaction.h>
-#include <kapplication.h>
+#include <tdeabc/stdaddressbook.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
 #include <kcolordialog.h>
 #include <kcommand.h>
 #include <kcombobox.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
 #include <kimageio.h>
 #include <klineedit.h>
-#include <klistbox.h>
-#include <klocale.h>
-#include <kmenubar.h>
-#include <kmessagebox.h>
+#include <tdelistbox.h>
+#include <tdelocale.h>
+#include <tdemenubar.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kpushbutton.h>
 #include <kprinter.h>
 #include <krun.h>
-#include <kspell.h>
+#include <tdespell.h>
 #include <kstatusbar.h>
 #include <kstandarddirs.h>
-#include <ktempfile.h>
+#include <tdetempfile.h>
 #include <dcopclient.h>
 
 #include "tcanvasitem.h"
@@ -119,7 +119,7 @@
 
 #define KBARCODE_UNDO_LIMIT 25
 
-using namespace KABC;
+using namespace TDEABC;
 
 LabelEditor::LabelEditor( TQWidget *parent, TQString _filename, const char *name, WFlags f )
     : DCOPObject( "LabelEditor" ),
@@ -131,7 +131,7 @@ LabelEditor::LabelEditor( TQWidget *parent, TQString _filename, const char *name
 
     description = TQString();
     d = new Definition();
-    m_token = new TokenProvider( TQT_TQPAINTDEVICE(KApplication::desktop()) );
+    m_token = new TokenProvider( TDEApplication::desktop() );
 
     statusBar()->insertItem( "", STATUS_ID_TEMPLATE, 0, true );
     statusBar()->insertItem( "", STATUS_ID_SIZE, 0, true );
@@ -139,7 +139,7 @@ LabelEditor::LabelEditor( TQWidget *parent, TQString _filename, const char *name
     statusBar()->setSizeGripEnabled( true );
     statusBar()->show();
 
-    c = new MyCanvas( TQT_TQOBJECT(this) );
+    c = new MyCanvas( this );
     c->setDoubleBuffering( true );
     c->setUpdatePeriod( CANVAS_UPDATE_PERIOD );
 
@@ -159,14 +159,14 @@ LabelEditor::LabelEditor( TQWidget *parent, TQString _filename, const char *name
 //    if( isFirstStart() )
 //        moveDockWindow( tools, TQt::DockLeft );
 
-    connect( cv, TQT_SIGNAL( doubleClickedItem(TCanvasItem*) ), TQT_TQOBJECT(this),  TQT_SLOT( doubleClickedItem(TCanvasItem*) ) );
-    connect( cv, TQT_SIGNAL( showContextMenu(TQPoint) ), TQT_TQOBJECT(this),  TQT_SLOT( showContextMenu(TQPoint) ) );
-    connect( cv, TQT_SIGNAL( movedSomething() ), TQT_TQOBJECT(this),  TQT_SLOT( setEdited() ) );
-    connect( KBarcodeSettings::getInstance(), TQT_SIGNAL( updateGrid( int ) ), cv, TQT_SLOT( updateGUI() ) );
-    connect( kapp, TQT_SIGNAL( aboutToQuit() ), TQT_TQOBJECT(this),  TQT_SLOT( saveConfig() ) );
+    connect( cv, TQ_SIGNAL( doubleClickedItem(TCanvasItem*) ), this,  TQ_SLOT( doubleClickedItem(TCanvasItem*) ) );
+    connect( cv, TQ_SIGNAL( showContextMenu(TQPoint) ), this,  TQ_SLOT( showContextMenu(TQPoint) ) );
+    connect( cv, TQ_SIGNAL( movedSomething() ), this,  TQ_SLOT( setEdited() ) );
+    connect( KBarcodeSettings::getInstance(), TQ_SIGNAL( updateGrid( int ) ), cv, TQ_SLOT( updateGUI() ) );
+    connect( kapp, TQ_SIGNAL( aboutToQuit() ), this,  TQ_SLOT( saveConfig() ) );
  
-    connect( history, TQT_SIGNAL( commandExecuted() ), cv, TQT_SLOT( updateGUI() ) );
-    connect( history, TQT_SIGNAL( commandExecuted() ), TQT_TQOBJECT(this),  TQT_SLOT( setEdited() ) );
+    connect( history, TQ_SIGNAL( commandExecuted() ), cv, TQ_SLOT( updateGUI() ) );
+    connect( history, TQ_SIGNAL( commandExecuted() ), this,  TQ_SLOT( setEdited() ) );
 
     if( !_filename.isEmpty() )
         openUrl( _filename );
@@ -181,7 +181,7 @@ LabelEditor::~LabelEditor()
 
 void LabelEditor::loadConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
     recentAct->loadEntries( config, "RecentFiles" );
 
     gridAct->setChecked( config->readBoolEntry("gridenabled", false ) );
@@ -190,7 +190,7 @@ void LabelEditor::loadConfig()
 
 void LabelEditor::saveConfig()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     recentAct->saveEntries( config, "RecentFiles" );
 
@@ -204,7 +204,7 @@ void LabelEditor::saveConfig()
 
 void LabelEditor::createCommandHistory()
 {
-    KConfig* config = kapp->config();
+    TDEConfig* config = kapp->config();
 
     if( undoAct && redoAct )
     {
@@ -226,8 +226,8 @@ void LabelEditor::createCommandHistory()
 
 void LabelEditor::createCommandHistoryActions()
 {
-    undoAct = (KAction*)actionCollection()->action("edit_undo");
-    redoAct = (KAction*)actionCollection()->action("edit_redo");
+    undoAct = (TDEAction*)actionCollection()->action("edit_undo");
+    redoAct = (TDEAction*)actionCollection()->action("edit_redo");
 
     undoAct->plug( editMenu, 0 );
     redoAct->plug( editMenu, 1 );
@@ -247,8 +247,8 @@ void LabelEditor::clearLabel()
     createCommandHistory();
     createCommandHistoryActions();
 
-    connect( history, TQT_SIGNAL( commandExecuted() ), cv, TQT_SLOT( updateGUI() ) );
-    connect( history, TQT_SIGNAL( commandExecuted() ), TQT_TQOBJECT(this),  TQT_SLOT( setEdited() ) );
+    connect( history, TQ_SIGNAL( commandExecuted() ), cv, TQ_SLOT( updateGUI() ) );
+    connect( history, TQ_SIGNAL( commandExecuted() ), this,  TQ_SLOT( setEdited() ) );
 
     m_edited = false;
 
@@ -303,7 +303,7 @@ bool LabelEditor::save( TQString name )
     if ( !f.open( IO_WriteOnly ) )
         return false;
 
-    save( TQT_TQIODEVICE(&f) );
+    save( &f );
 
     m_token->setLabelName( filename.right( filename.length() - filename.findRev( "/" ) - 1 ) );
     // maybe we should redraw all items on the canvas now.
@@ -437,47 +437,47 @@ bool LabelEditor::newLabel()
 
 void LabelEditor::setupActions()
 {
-    KAction* newAct = KStdAction::openNew( TQT_TQOBJECT(this), TQT_SLOT(startEditor()), actionCollection() );
-    KAction* loadAct = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(startLoadEditor()), actionCollection() );
-    KAction* quitAct = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT(quit()), actionCollection());
-    KAction* closeAct = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection(), "close" );
-    closeLabelAct = new KAction( i18n("Close &Label" ), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT( closeLabel() ), actionCollection() );
+    TDEAction* newAct = KStdAction::openNew( this, TQ_SLOT(startEditor()), actionCollection() );
+    TDEAction* loadAct = KStdAction::open( this, TQ_SLOT(startLoadEditor()), actionCollection() );
+    TDEAction* quitAct = KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
+    TDEAction* closeAct = KStdAction::close( this, TQ_SLOT( close() ), actionCollection(), "close" );
+    closeLabelAct = new TDEAction( i18n("Close &Label" ), 0, 0, this,  TQ_SLOT( closeLabel() ), actionCollection() );
 
-    recentAct = new KRecentFilesAction( i18n("&Recent Files"), 0, TQT_TQOBJECT(this),  TQT_SLOT( loadRecentEditor( const KURL& ) ) );
+    recentAct = new TDERecentFilesAction( i18n("&Recent Files"), 0, this,  TQ_SLOT( loadRecentEditor( const KURL& ) ) );
 
-    KAction* importPrintFileAct = new KAction( i18n("&Import and Print Batch File..."), BarIconSet( "fileprint" ), 0, TQT_TQOBJECT(this),  TQT_SLOT( batchPrint() ), actionCollection() );
+    TDEAction* importPrintFileAct = new TDEAction( i18n("&Import and Print Batch File..."), BarIconSet( "document-print" ), 0, this,  TQ_SLOT( batchPrint() ), actionCollection() );
 
-    saveAct = KStdAction::save( TQT_TQOBJECT(this), TQT_SLOT( save() ), actionCollection(), "save" );
-    saveAsAct = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT( saveas() ), actionCollection(), "saveas" );
-    descriptionAct = new KAction( i18n("&Change description..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT(changeDes()), actionCollection() );
-    deleteAct = new KAction( i18n("&Delete Object"), TQIconSet( BarIcon("editdelete") ), Key_Delete, TQT_TQOBJECT(cv), TQT_SLOT( deleteCurrent() ), actionCollection() );
-    editPropAct = new KAction( i18n("&Properties..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT( doubleClickedCurrent() ), actionCollection() );
-    printAct = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT( print() ), actionCollection(), "print" );
-    bcpAct = new KAction( i18n("Print to &Barcode Printer..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT( printBCP() ), actionCollection() );
-    imgAct = new KAction( i18n("Print to &Image..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT(printImage() ), actionCollection() );
-    changeSizeAct = new KAction( i18n("&Change Label..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT( changeSize() ), actionCollection() );
-    barcodeAct = new KAction( i18n("Insert &Barcode"), TQIconSet( BarIcon("barcode") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertBarcode() ), actionCollection() );
+    saveAct = KStdAction::save( this, TQ_SLOT( save() ), actionCollection(), "save" );
+    saveAsAct = KStdAction::saveAs( this, TQ_SLOT( saveas() ), actionCollection(), "saveas" );
+    descriptionAct = new TDEAction( i18n("&Change description..."), 0, 0, this,  TQ_SLOT(changeDes()), actionCollection() );
+    deleteAct = new TDEAction( i18n("&Delete Object"), TQIconSet( BarIcon("edit-delete") ), Key_Delete, cv, TQ_SLOT( deleteCurrent() ), actionCollection() );
+    editPropAct = new TDEAction( i18n("&Properties..."), 0, 0, this,  TQ_SLOT( doubleClickedCurrent() ), actionCollection() );
+    printAct = KStdAction::print( this, TQ_SLOT( print() ), actionCollection(), "print" );
+    bcpAct = new TDEAction( i18n("Print to &Barcode Printer..."), 0, 0, this,  TQ_SLOT( printBCP() ), actionCollection() );
+    imgAct = new TDEAction( i18n("Print to &Image..."), 0, 0, this,  TQ_SLOT(printImage() ), actionCollection() );
+    changeSizeAct = new TDEAction( i18n("&Change Label..."), 0, 0, this,  TQ_SLOT( changeSize() ), actionCollection() );
+    barcodeAct = new TDEAction( i18n("Insert &Barcode"), TQIconSet( BarIcon("barcode") ), 0, this,  TQ_SLOT( insertBarcode() ), actionCollection() );
     barcodeAct->setEnabled( Barkode::haveBarcode() );
 
-    pictureAct = new KAction( i18n("Insert &Picture"), TQIconSet( BarIcon("inline_image") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertPicture() ), actionCollection() );
-    textAct = new KAction( i18n("Insert &Text"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertText() ), actionCollection() );
-    textDataAct = new KAction( i18n("Insert &Data Field"), TQIconSet( BarIcon("contents") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertDataText() ), actionCollection() );
-    textLineAct = new KAction( i18n("Insert &Text Line"), TQIconSet( BarIcon("text") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertTextLine() ), actionCollection() );
-    lineAct = new KAction( i18n("Insert &Line"), TQIconSet( BarIcon("kbarcodelinetool") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertLine() ), actionCollection() );
-    rectAct = new KAction( i18n("Insert &Rectangle"), TQIconSet( BarIcon("kbarcoderect") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertRect() ), actionCollection() );
-    circleAct = new KAction( i18n("Insert &Ellipse"), TQIconSet( BarIcon("kbarcodeellipse") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( insertCircle() ), actionCollection() );
-    spellAct = KStdAction::spelling( TQT_TQOBJECT(this), TQT_SLOT(spellCheck()), actionCollection(), "spell" );
-    gridAct = new KToggleAction( i18n("&Grid"), TQIconSet( BarIcon("kbarcodegrid") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( toggleGrid() ), actionCollection() );
-    previewAct = new KAction( i18n("&Preview..."), 0, 0, TQT_TQOBJECT(this),  TQT_SLOT( preview() ), actionCollection() );
-    sep = new KActionSeparator( TQT_TQOBJECT(this) );
-    cutAct = KStdAction::cut( TQT_TQOBJECT(this), TQT_SLOT( cut() ), actionCollection(), "cut" );
-    copyAct = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT( copy() ), actionCollection(), "copy" );
-    pasteAct = KStdAction::paste( TQT_TQOBJECT(this), TQT_SLOT( paste() ), actionCollection(), "paste" );
-    selectAllAct = KStdAction::selectAll( TQT_TQOBJECT(cv), TQT_SLOT( selectAll() ), actionCollection(), "select_all" );
-    deSelectAllAct = KStdAction::deselect( TQT_TQOBJECT(cv), TQT_SLOT( deSelectAll() ), actionCollection(), "de_select_all" );
-    addressBookAct = new KAction( i18n("Address&book"), TQIconSet( BarIcon("kaddressbook") ), 0, TQT_TQOBJECT(this),  TQT_SLOT( launchAddressBook() ), actionCollection() );
-    KAction* singleBarcodeAct = new KAction(i18n("&Create Single Barcode..."), "",
-                                0, TQT_TQOBJECT(this),  TQT_SLOT(startBarcodeGen()),
+    pictureAct = new TDEAction( i18n("Insert &Picture"), TQIconSet( BarIcon("inline_image") ), 0, this,  TQ_SLOT( insertPicture() ), actionCollection() );
+    textAct = new TDEAction( i18n("Insert &Text"), TQIconSet( BarIcon("text") ), 0, this,  TQ_SLOT( insertText() ), actionCollection() );
+    textDataAct = new TDEAction( i18n("Insert &Data Field"), TQIconSet( BarIcon("contents") ), 0, this,  TQ_SLOT( insertDataText() ), actionCollection() );
+    textLineAct = new TDEAction( i18n("Insert &Text Line"), TQIconSet( BarIcon("text") ), 0, this,  TQ_SLOT( insertTextLine() ), actionCollection() );
+    lineAct = new TDEAction( i18n("Insert &Line"), TQIconSet( BarIcon("kbarcodelinetool") ), 0, this,  TQ_SLOT( insertLine() ), actionCollection() );
+    rectAct = new TDEAction( i18n("Insert &Rectangle"), TQIconSet( BarIcon("kbarcoderect") ), 0, this,  TQ_SLOT( insertRect() ), actionCollection() );
+    circleAct = new TDEAction( i18n("Insert &Ellipse"), TQIconSet( BarIcon("kbarcodeellipse") ), 0, this,  TQ_SLOT( insertCircle() ), actionCollection() );
+    spellAct = KStdAction::spelling( this, TQ_SLOT(spellCheck()), actionCollection(), "spell" );
+    gridAct = new TDEToggleAction( i18n("&Grid"), TQIconSet( BarIcon("kbarcodegrid") ), 0, this,  TQ_SLOT( toggleGrid() ), actionCollection() );
+    previewAct = new TDEAction( i18n("&Preview..."), 0, 0, this,  TQ_SLOT( preview() ), actionCollection() );
+    sep = new TDEActionSeparator( this );
+    cutAct = KStdAction::cut( this, TQ_SLOT( cut() ), actionCollection(), "cut" );
+    copyAct = KStdAction::copy( this, TQ_SLOT( copy() ), actionCollection(), "copy" );
+    pasteAct = KStdAction::paste( this, TQ_SLOT( paste() ), actionCollection(), "paste" );
+    selectAllAct = KStdAction::selectAll( cv, TQ_SLOT( selectAll() ), actionCollection(), "select_all" );
+    deSelectAllAct = KStdAction::deselect( cv, TQ_SLOT( deSelectAll() ), actionCollection(), "de_select_all" );
+    addressBookAct = new TDEAction( i18n("Address&book"), TQIconSet( BarIcon("kaddressbook") ), 0, this,  TQ_SLOT( launchAddressBook() ), actionCollection() );
+    TDEAction* singleBarcodeAct = new TDEAction(i18n("&Create Single Barcode..."), "",
+                                0, this,  TQ_SLOT(startBarcodeGen()),
                                 actionCollection(), "create" );
     singleBarcodeAct->setEnabled( Barkode::haveBarcode() );
 
@@ -490,7 +490,7 @@ void LabelEditor::setupActions()
     copyAct->plug( toolBar() );
     pasteAct->plug( toolBar() );
 
-    tools = new KToolBar( this, this->leftDock(), true, "tools" );
+    tools = new TDEToolBar( this, this->leftDock(), true, "tools" );
 
     barcodeAct->plug( tools );
     pictureAct->plug( tools );
@@ -500,19 +500,19 @@ void LabelEditor::setupActions()
     lineAct->plug( tools );
     rectAct->plug( tools );
     circleAct->plug( tools );
-    (new KActionSeparator( TQT_TQOBJECT(this) ))->plug( tools );
+    (new TDEActionSeparator( this ))->plug( tools );
 //    spellAct->plug( tools );  // KDE 3.2
     gridAct->plug( tools );
 
     DSMainWindow::setupActions();
-    connect( recentAct, TQT_SIGNAL( urlSelected( const KURL& ) ), TQT_TQOBJECT(this),  TQT_SLOT( startLoadRecentEditor( const KURL& ) ) );
+    connect( recentAct, TQ_SIGNAL( urlSelected( const KURL& ) ), this,  TQ_SLOT( startLoadRecentEditor( const KURL& ) ) );
 
-    KPopupMenu* fileMenu = new KPopupMenu( this );
-    editMenu = new KPopupMenu( this );
-    KPopupMenu* viewMenu = new KPopupMenu( this );
-    KPopupMenu* insMenu = new KPopupMenu( this );
-    KPopupMenu* toolMenu = new KPopupMenu( this );
-    KPopupMenu* barMenu = new KPopupMenu( this );
+    TDEPopupMenu* fileMenu = new TDEPopupMenu( this );
+    editMenu = new TDEPopupMenu( this );
+    TDEPopupMenu* viewMenu = new TDEPopupMenu( this );
+    TDEPopupMenu* insMenu = new TDEPopupMenu( this );
+    TDEPopupMenu* toolMenu = new TDEPopupMenu( this );
+    TDEPopupMenu* barMenu = new TDEPopupMenu( this );
 
     menuBar()->removeItemAt( 0 );
     menuBar()->insertItem( i18n("&File"), fileMenu, -1, 0 );
@@ -575,26 +575,26 @@ void LabelEditor::setupActions()
 
 void LabelEditor::setupContextMenu()
 {
-    m_mnuContext = new KPopupMenu( this );
+    m_mnuContext = new TDEPopupMenu( this );
     m_mnuContext->setCheckable( true );
     
-    KPopupMenu* orderMenu = new KPopupMenu( m_mnuContext );
-    orderMenu->insertItem( i18n("&On Top"), TQT_TQOBJECT(this),  TQT_SLOT( onTopCurrent() ) );
-    orderMenu->insertItem( i18n("&Raise"), TQT_TQOBJECT(this),  TQT_SLOT( raiseCurrent() ) );
-    orderMenu->insertItem( i18n("&Lower"), TQT_TQOBJECT(this),  TQT_SLOT( lowerCurrent() ) );
-    orderMenu->insertItem( i18n("&To Background"), TQT_TQOBJECT(this),  TQT_SLOT( backCurrent() ) );
+    TDEPopupMenu* orderMenu = new TDEPopupMenu( m_mnuContext );
+    orderMenu->insertItem( i18n("&On Top"), this,  TQ_SLOT( onTopCurrent() ) );
+    orderMenu->insertItem( i18n("&Raise"), this,  TQ_SLOT( raiseCurrent() ) );
+    orderMenu->insertItem( i18n("&Lower"), this,  TQ_SLOT( lowerCurrent() ) );
+    orderMenu->insertItem( i18n("&To Background"), this,  TQ_SLOT( backCurrent() ) );
 
-    KPopupMenu* centerMenu = new KPopupMenu( m_mnuContext );
-    centerMenu->insertItem( i18n("Center &Horizontally"), TQT_TQOBJECT(this),  TQT_SLOT( centerHorizontal() ) );
-    centerMenu->insertItem( i18n("Center &Vertically"), TQT_TQOBJECT(this),  TQT_SLOT( centerVertical() ) );
+    TDEPopupMenu* centerMenu = new TDEPopupMenu( m_mnuContext );
+    centerMenu->insertItem( i18n("Center &Horizontally"), this,  TQ_SLOT( centerHorizontal() ) );
+    centerMenu->insertItem( i18n("Center &Vertically"), this,  TQ_SLOT( centerVertical() ) );
 
     m_mnuContext->insertItem( i18n("&Order"), orderMenu );
     m_mnuContext->insertItem( i18n("&Center"), centerMenu );
     m_mnuContext->insertSeparator();
-    m_mnuContext->insertItem( SmallIcon("editdelete"), i18n("&Delete"), cv, TQT_SLOT( deleteCurrent() ) );
-    m_mnuContext->insertItem( i18n("&Protect Position and Size"), TQT_TQOBJECT(this),  TQT_SLOT( lockItem() ), 0, ID_LOCK_ITEM );
+    m_mnuContext->insertItem( SmallIcon("edit-delete"), i18n("&Delete"), cv, TQ_SLOT( deleteCurrent() ) );
+    m_mnuContext->insertItem( i18n("&Protect Position and Size"), this,  TQ_SLOT( lockItem() ), 0, ID_LOCK_ITEM );
     m_mnuContext->insertSeparator();
-    m_mnuContext->insertItem( i18n("&Properties"), TQT_TQOBJECT(this),  TQT_SLOT( doubleClickedCurrent() ) );
+    m_mnuContext->insertItem( i18n("&Properties"), this,  TQ_SLOT( doubleClickedCurrent() ) );
 }
 
 void LabelEditor::insertBarcode()
@@ -801,7 +801,7 @@ void LabelEditor::batchPrint( BatchPrinter* batch, int copies, int mode )
     if( !buffer.open( IO_WriteOnly ) )
         return;
 
-    save( TQT_TQIODEVICE(&buffer) );
+    save( &buffer );
 
     batch->setBuffer( &buffer );
     batch->setSerial( TQString(), 1 );
@@ -947,10 +947,10 @@ void LabelEditor::preview()
     if( !buffer.open( IO_WriteOnly ) )
         return;
 
-    save( TQT_TQIODEVICE(&buffer) );
+    save( &buffer );
 
     // No need to delete pd as it has WDestructiveClose set!
-    PreviewDialog* pd = new PreviewDialog( TQT_TQIODEVICE(&buffer), d, fileName(), this );
+    PreviewDialog* pd = new PreviewDialog( &buffer, d, fileName(), this );
     pd->exec();
 }
 
