@@ -30,7 +30,7 @@ class TQIODevice;
 class TQLabel;
 class TQWidget;
 class PreviewDialog : public TQDialog  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public: 
         PreviewDialog( TQIODevice* device, Definition* d, TQString filename, TQWidget *parent=0, const char *name=0);
