@@ -24,7 +24,7 @@
 
 class KURL;
 
-typedef struct labelprinterdata {
+struct labelprinterdata {
    int articleEvent1;
    int articleEvent2;
    int articleEvent3;
@@ -46,7 +46,7 @@ typedef struct labelprinterdata {
    TQString quote;
 };
 
-typedef struct PageFormatInfo
+struct PageFormatInfo
 {
     KPrinter::PageSize kprinter;
     const char* shortName; // Short name
@@ -58,7 +58,7 @@ typedef struct PageFormatInfo
 class KPrinter;
 class KComboBox;
 class PrinterSettings: public TQObject  {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         enum { High = TQPrinter::HighResolution, Middle, VeryHigh };
