@@ -89,7 +89,7 @@ SqlTables::SqlTables( TQObject* parent )
     connected = false;
     loadConfig();
 
-    connect( kapp, TQT_SIGNAL( aboutToQuit() ), this, TQT_SLOT( saveConfig() ) );
+    connect( kapp, TQ_SIGNAL( aboutToQuit() ), this, TQ_SLOT( saveConfig() ) );
 }
 
 SqlTables::~SqlTables()
@@ -521,7 +521,7 @@ SqlWidget::SqlWidget( bool showlabel, TQWidget* parent, const char* name )
 
     TQGroupBox* groupDatabase = new TQGroupBox( this );
     groupDatabase->setTitle( i18n( "Database Settings" ) );
-    groupDatabase->setColumnLayout(0, Qt::Vertical );
+    groupDatabase->setColumnLayout(0, TQt::Vertical );
     groupDatabase->layout()->setSpacing( 6 );
     groupDatabase->layout()->setMargin( 11 );
     TQVBoxLayout* groupDatabaseLayout = new TQVBoxLayout( groupDatabase->layout() );
@@ -584,7 +584,7 @@ SqlWidget::SqlWidget( bool showlabel, TQWidget* parent, const char* name )
 
     layout->add( groupDatabase );
 
-    connect( buttonTest, TQT_SIGNAL( clicked() ), this, TQT_SLOT( testSettings() ) );
+    connect( buttonTest, TQ_SIGNAL( clicked() ), this, TQ_SLOT( testSettings() ) );
 
     const mysqldata & sqldata = SqlTables::getInstance()->getData();
     m_username->setText( sqldata.username );
