@@ -114,9 +114,9 @@ void TokenDialog::setupStackPage2()
 
     radioVariable->setChecked( true );
 
-    connect( radioVariable, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( radioSQLQuery, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( radioJavaScript, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
+    connect( radioVariable, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( radioSQLQuery, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( radioJavaScript, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
 
     page2->addWidget( stackPage2 );
 }
@@ -160,8 +160,8 @@ void TokenDialog::setupStack2Page1()
     right->setStretchFactor( allList, 2 );
     splitter->setSizes( sizes );
 
-    connect( category, TQT_SIGNAL( executed( TQListBoxItem* ) ), this, TQT_SLOT( categoryChanged( TQListBoxItem* ) ) );
-    connect( allList, TQT_SIGNAL( clicked( TQListViewItem* ) ), this, TQT_SLOT( itemChanged( TQListViewItem* ) ) );
+    connect( category, TQ_SIGNAL( executed( TQListBoxItem* ) ), this, TQ_SLOT( categoryChanged( TQListBoxItem* ) ) );
+    connect( allList, TQ_SIGNAL( clicked( TQListViewItem* ) ), this, TQ_SLOT( itemChanged( TQListViewItem* ) ) );
 
     initAll();
 
@@ -178,8 +178,8 @@ void TokenDialog::setupStack2Page2()
     labelList->setColumnWidthMode( 0, TQListView::Maximum );
     labelList->setColumnWidthMode( 1, TQListView::Maximum );
 
-    connect( labelList, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( enableControls() ) );
-    connect( labelList, TQT_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ), this, TQT_SLOT( accept() ) );
+    connect( labelList, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableControls() ) );
+    connect( labelList, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ), this, TQ_SLOT( accept() ) );
 
     page3->addWidget( stack2Page2 );
 }
@@ -202,11 +202,11 @@ void TokenDialog::setupStack2Page3()
     if( !listVariable->count() )
         radioVariableExisting->setEnabled( false );
 
-    connect( radioVariableNew, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( radioVariableExisting, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( editVariable, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( enableControls() ) );
-    connect( listVariable, TQT_SIGNAL( highlighted( int ) ), this, TQT_SLOT( enableControls() ) );
-    connect( listVariable, TQT_SIGNAL( doubleClicked( TQListBoxItem*, const TQPoint & ) ), this, TQT_SLOT( accept() ) );
+    connect( radioVariableNew, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( radioVariableExisting, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( editVariable, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( enableControls() ) );
+    connect( listVariable, TQ_SIGNAL( highlighted( int ) ), this, TQ_SLOT( enableControls() ) );
+    connect( listVariable, TQ_SIGNAL( doubleClicked( TQListBoxItem*, const TQPoint & ) ), this, TQ_SLOT( accept() ) );
 
     page3->addWidget( stack2Page3 );
 }
@@ -232,8 +232,8 @@ void TokenDialog::setupStack2Page4()
     textQueryResults = new TQTextBrowser( stack2Page4 );
     textQueryResults->setReadOnly( true );
 
-    connect( buttonQuery, TQT_SIGNAL( clicked() ), this, TQT_SLOT( testQuery() ) );
-    connect( editQuery, TQT_SIGNAL( textChanged( const TQString & ) ), this, TQT_SLOT( enableControls() ) );
+    connect( buttonQuery, TQ_SIGNAL( clicked() ), this, TQ_SLOT( testQuery() ) );
+    connect( editQuery, TQ_SIGNAL( textChanged( const TQString & ) ), this, TQ_SLOT( enableControls() ) );
         
     page3->addWidget( stack2Page4 );
 }
@@ -245,7 +245,7 @@ void TokenDialog::setupStack2Page5()
     editJavaScript = new DSTextEdit( stack2Page5 );
     editJavaScript->setText( i18n("/* Place your JavaScript code into this text field. */\n") );
 
-    connect( editJavaScript, TQT_SIGNAL( textChanged() ), TQT_SLOT( enableControls() ) );
+    connect( editJavaScript, TQ_SIGNAL( textChanged() ), TQ_SLOT( enableControls() ) );
 
     page3->addWidget( stack2Page5 );
 }
