@@ -39,7 +39,7 @@ class DSTextEdit;
 
 class TokenDialog : public KWizard {
     
- Q_OBJECT
+ TQ_OBJECT
   
 
  public:
